@@ -214,6 +214,45 @@ function parseVenue(response) {
         placeDialog.venueMajor = venue.mayor.user.firstName + " " + venue.mayor.user.lastName[0] + ".";
         placeDialog.venueMajorPhoto = venue.mayor.user.photo;
     }
+    // Parse venue tips
+    tipsModel.clear();
+    console.log("tips: " + venue.tips.count);
+    if(venue.tips.count>0) {
+        var tipCounter = 0;
+        for(var i in venue.tips.groups[0].items) {
+            var tip = venue.tips.groups[0].items[i];
+            console.log("tip: " + tip);
+            var createdAt = new Date(parseInt(tip.createdAt,10)*1000);
+            var createdAgo = prettyDate(createdAt);
+            tipsModel.append({
+                             "tipID": tip.id,
+                             "tipText": tip.text,
+                             "tipAge": "Added " + createdAgo
+            });
+            tipCounter++;
+            if(tipCounter>0) {
+                break;
+            }
+        }
+    }
+}
+
+function addTip(venueID, text) {
+    waiting.state = "shown";
+    var url = "https://api.foursquare.com/v2/tips/add?";
+    url += "venueId=" + venueID + "&";
+    url += "text=" + encodeURIComponent(text) + "&";
+    url += getAccessTokenParameter();
+    doWebRequest("POST", url, "", showDone);
+}
+
+function markVenueToDo(venueID, text) {
+    var url = "https://api.foursquare.com/v2/venues/" + venueID + "/marktodo?";
+    if(text!="" && text.length>0) {
+        url += "text=" + encodeURIComponent(text) + "&";
+    }
+    url += getAccessTokenParameter();
+    doWebRequest("POST", url, "", showDone);
 }
 
 function loadMyCheckins() {
